@@ -2,6 +2,8 @@ import asyncio
 import typing as t
 from collections import defaultdict
 
+from aiomisc.counters import Statistic
+
 
 _StorageType = t.DefaultDict[t.Any, asyncio.Future]
 _EventObjectStoreType = t.Dict[
@@ -9,8 +11,13 @@ _EventObjectStoreType = t.Dict[
 ]
 
 
+class ContextStatistic(Statistic):
+    get: int
+    set: int
+
+
 class Context:
-    __slots__ = ("_storage", "_loop")
+    __slots__ = ("_storage", "_loop", "_statistic")
 
     _EVENT_OBJECTS = dict()     # type: _EventObjectStoreType
 
@@ -22,11 +29,14 @@ class Context:
         self._loop = loop
         self._storage = defaultdict(loop.create_future)  # type: _StorageType
         self._EVENT_OBJECTS[loop] = self
+        self._statistic = ContextStatistic()
 
     def __getitem__(self, item: t.Any) -> t.Any:
+        self._statistic.get += 1
         return self._storage[item]
 
     def __setitem__(self, item: t.Any, value: t.Any) -> None:
+        self._statistic.set += 1
         self._loop.call_soon_threadsafe(self.__setter, item, value)
 
     def __setter(self, item: t.Any, value: t.Any) -> None:
