@@ -4,6 +4,7 @@ import typing as t
 from functools import partial
 
 from . import utils
+from .counters import Statistic
 
 
 log = logging.getLogger(__name__)
@@ -11,6 +12,13 @@ ExceptionsType = t.Tuple[t.Type[Exception], ...]
 CallbackType = t.Callable[..., t.Union[t.Awaitable[t.Any], t.Any]]
 
 
+class PeriodicCallbackStatistic(Statistic):
+    call_count: int
+    done: int
+    fail: int
+    sum_time: float
+
+
 class PeriodicCallback:
     """
     .. note::
@@ -20,13 +28,17 @@ class PeriodicCallback:
 
     """
 
-    __slots__ = "_cb", "_closed", "_task", "_loop", "_handle", "__name"
+    __slots__ = (
+        "_cb", "_closed", "_task", "_loop", "_handle", "__name",
+        "_statistic",
+    )
 
     def __init__(
         self, coroutine_func: CallbackType,
         *args: t.Any, **kwargs: t.Any
     ):
 
+        self._statistic = PeriodicCallbackStatistic()
         self.__name = repr(coroutine_func)
         self._cb = partial(
             utils.awaitable(coroutine_func), *args, **kwargs
@@ -80,7 +92,21 @@ class PeriodicCallback:
                 runner(suppress_exceptions),        # type: ignore
             )
 
+            start_time = self._loop.time()
+
             self._task.add_done_callback(call)
+            self._task.add_done_callback(lambda t: do_stat(t, start_time))
+
+        def do_stat(task: asyncio.Task, start_time: float) -> None:
+            self._statistic.call_count += 1
+            self._statistic.sum_time += self._loop.time() - start_time
+
+            if task.cancelled():
+                self._statistic.fail += 1
+            elif task.exception():
+                self._statistic.fail += 1
+            else:
+                self._statistic.done += 1
 
         def call(*_: t.Any) -> None:
             if self._handle is not None:
