@@ -127,7 +127,7 @@ def create_default_event_loop(
     asyncio.set_event_loop(loop)
 
     pool_size = pool_size or cpu_count()
-    thread_pool = ThreadPoolExecutor(pool_size)
+    thread_pool = ThreadPoolExecutor(pool_size, statistic_name="default")
     loop.set_default_executor(thread_pool)
 
     return loop, thread_pool
