@@ -16,6 +16,7 @@ from typing import (
     Any, Callable, Coroutine, Dict, Mapping, Optional, Set, Tuple, Type,
 )
 
+from aiomisc.counters import Statistic
 from aiomisc.log.config import LOG_FORMAT, LOG_LEVEL
 from aiomisc.thread_pool import threaded
 from aiomisc.utils import bind_socket, cancel_tasks
@@ -32,6 +33,18 @@ if sys.version_info < (3, 7):
     )
 
 
+class WorkerPoolStatistic(Statistic):
+    processes: int
+    queue_size: int
+    submitted: int
+    sum_time: float
+    done: int
+    success: int
+    error: int
+    bad_auth: int
+    task_added: int
+
+
 class WorkerPool:
     tasks: asyncio.Queue
     server: asyncio.AbstractServer
@@ -111,6 +124,7 @@ class WorkerPool:
         self.__task_store: Set[asyncio.Task] = set()
         self.__closing = False
         self.__starting: Dict[str, asyncio.Future] = dict()
+        self._statistic = WorkerPoolStatistic()
         self.processes: Set[Popen] = set()
         self.workers = workers
         self.tasks = asyncio.Queue(maxsize=max_overflow)
@@ -129,6 +143,16 @@ class WorkerPool:
             self.__loop = asyncio.get_event_loop()
         return self.__loop
 
+    @staticmethod
+    async def __wait_closed(writer: asyncio.StreamWriter) -> None:
+        if writer.is_closing():
+            return
+
+        writer.close()
+
+        if hasattr(writer, "wait_closed"):
+            await writer.wait_closed()
+
     async def __handle_client(
         self, reader: asyncio.StreamReader, writer: asyncio.StreamWriter,
     ) -> None:
@@ -150,15 +174,19 @@ class WorkerPool:
             kwargs: Dict[str, Any], result_future: asyncio.Future,
         ) -> None:
             await send(PacketTypes.REQUEST, (func, args, kwargs))
+            self._statistic.submitted += 1
 
             packet_type, result = await receive()
+            self._statistic.done += 1
 
             if packet_type == PacketTypes.RESULT:
                 result_future.set_result(result)
+                self._statistic.success += 1
                 return None
 
             if packet_type == PacketTypes.EXCEPTION:
                 result_future.set_exception(result)
+                self._statistic.error += 1
                 return None
 
             if packet_type == PacketTypes.CANCELLED:
@@ -183,6 +211,7 @@ class WorkerPool:
 
             if digest != hasher.digest():
                 exc = AuthenticationError("Invalid cookie")
+                self._statistic.bad_auth += 1
                 await send(PacketTypes.EXCEPTION, exc)
                 raise exc
 
@@ -218,57 +247,66 @@ class WorkerPool:
                 starting.set_result(None)
                 start_event.set()
 
-            while True:
-                func: Callable
-                args: Tuple[Any, ...]
-                kwargs: Dict[str, Any]
-                result_future: asyncio.Future
-                process_future: asyncio.Future
+            try:
+                while True:
+                    func: Callable
+                    args: Tuple[Any, ...]
+                    kwargs: Dict[str, Any]
+                    result_future: asyncio.Future
+                    process_future: asyncio.Future
 
-                (
-                    func, args, kwargs, result_future, process_future,
-                ) = await self.tasks.get()
+                    self._statistic.processes += 1
+                    (
+                        func, args, kwargs, result_future, process_future,
+                    ) = await self.tasks.get()
 
-                try:
-                    if process_future.done():
-                        continue
+                    try:
+                        if process_future.done():
+                            continue
 
-                    process_future.set_result(process)
+                        process_future.set_result(process)
 
-                    if result_future.done():
-                        continue
+                        if result_future.done():
+                            continue
 
-                    await step(func, args, kwargs, result_future)
-                except asyncio.IncompleteReadError:
-                    await self.__wait_process(process)
-                    self.__on_exit(process)
+                        await step(func, args, kwargs, result_future)
+                    except asyncio.IncompleteReadError:
+                        await self.__wait_process(process)
+                        self.__on_exit(process)
 
-                    result_future.set_exception(
-                        ProcessError(
-                            "Process {!r} exited with code {!r}".format(
-                                process, process.returncode,
+                        result_future.set_exception(
+                            ProcessError(
+                                "Process {!r} exited with code {!r}".format(
+                                    process, process.returncode,
+                                ),
                             ),
-                        ),
-                    )
-                    break
-                except Exception as e:
-                    if not result_future.done():
-                        self.loop.call_soon(result_future.set_exception, e)
+                        )
+                        break
+                    except Exception as e:
+                        if not result_future.done():
+                            self.loop.call_soon(result_future.set_exception, e)
 
-                    if not writer.is_closing():
-                        self.loop.call_soon(writer.close)
+                        if not writer.is_closing():
+                            self.loop.call_soon(writer.close)
 
-                    await self.__wait_process(process)
-                    self.__on_exit(process)
+                        await self.__wait_process(process)
+                        self.__on_exit(process)
 
-                    raise
+                        raise
+                    finally:
+                        self._statistic.processes -= 1
+            finally:
+                await self.__wait_closed(writer)
 
         start_event = asyncio.Event()
         task = self.loop.create_task(handler(start_event))
         await start_event.wait()
         self.__task_add(task)
 
+        await task
+
     def __task_add(self, task: asyncio.Task) -> None:
+        self._statistic.task_added += 1
         task.add_done_callback(self.__task_store.remove)
         self.__task_store.add(task)
 
