@@ -32,7 +32,7 @@ def services(service: _TestService, async_sleep):
 
 async def test_loop_fixture(
     service: _TestService,
-    loop: asyncio.AbstractEventLoop
+    loop: asyncio.AbstractEventLoop,
 ):
     assert service.loop is service.loop_on_init is loop
 
